Class ImageProcessError
- java.lang.Object
-
- com.volcengine.ark.runtime.model.responses.tool.imageprocess.ImageProcessError
-
public class ImageProcessError extends Object
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classImageProcessError.Builder
-
Constructor Summary
Constructors Constructor Description ImageProcessError()
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description static ImageProcessError.Builderbuilder()StringgetMessage()voidsetMessage(String message)StringtoString()
-